@@ -53,9 +53,6 @@ class Config(APIView):
                 "markdown": {
                     "blockdiag": reverse("bridger:blockdiag", request=request)
                 },
-                "clubhouse": {
-                    "endpoint": reverse("bridger:clubhouse-list", request=request),
-                    "add": reverse("bridger:clubhouse-list", request=request),
-                },
+                "clubhouse": bridger_settings.CLUBHOUSE_CONFIG(request),
             }
         )
